@@ -14,7 +14,9 @@ logging.basicConfig(format=FORMAT)
 
 
 def main():
-    description = f"Solar Device Command Utility, version: {__version__}, {__version_comment__}"
+    description = (
+        f"Solar Device Command Utility, version: {__version__}, {__version_comment__}"
+    )
     parser = ArgumentParser(description=description)
     parser.add_argument(
         "-n",
@@ -137,7 +139,24 @@ def main():
         help="Specifies the password to use for authenticated mqtt broker publishing",
         default=None,
     )
-    parser.add_argument("-c", "--command", nargs="?", const="help", help="Command to run")
+    parser.add_argument(
+        "--udpport",
+        type=str,
+        help="Specifies the UDP port if needed (default: 5555)",
+        default="5555",
+    )
+    parser.add_argument(
+        "--mongo_url",
+        type=str,
+        help="Mongo connection url, example mongodb://user:password@ip:port/admindb",
+    )
+    parser.add_argument(
+        "--mongo_db",
+        type=str,
+        help="Mongo db name (default: mppsolar)",
+        default="mppsolar",
+    )
+    parser.add_argument("-c", "--command", nargs="?", const="help", help="Command to run; or list of hash separated commands to run")
     if parser.prog == "jkbms":
         parser.add_argument(
             "-C",
@@ -160,9 +179,13 @@ def main():
         )
     parser.add_argument("--daemon", action="store_true", help="Run as daemon")
     parser.add_argument("--getstatus", action="store_true", help="Get Inverter Status")
-    parser.add_argument("--getsettings", action="store_true", help="Get Inverter Settings")
+    parser.add_argument(
+        "--getsettings", action="store_true", help="Get Inverter Settings"
+    )
 
-    parser.add_argument("-v", "--version", action="store_true", help="Display the version")
+    parser.add_argument(
+        "-v", "--version", action="store_true", help="Display the version"
+    )
     parser.add_argument(
         "-D",
         "--debug",
@@ -198,10 +221,20 @@ def main():
         return None
 
     mqtt_broker = MqttBroker(
-        name=args.mqttbroker, port=args.mqttport, username=args.mqttuser, password=args.mqttpass
+        name=args.mqttbroker,
+        port=args.mqttport,
+        username=args.mqttuser,
+        password=args.mqttpass,
+    )
+    mqtt_broker.set(
+        "results_topic", (args.mqtttopic if args.mqtttopic is not None else prog_name)
     )
-    mqtt_broker.set("results_topic", (args.mqtttopic if args.mqtttopic is not None else prog_name))
     log.debug(mqtt_broker)
+    udp_port = args.udpport
+    log.debug(f"udp port {udp_port}")
+    mongo_url = args.mongo_url
+    mongo_db = args.mongo_db
+    log.debug(f"Using Mongo {mongo_url} with {mongo_db}")
     ##
     filter = args.filter
     excl_filter = args.exclfilter
@@ -235,7 +268,9 @@ def main():
         sections = config.sections()
         # Check setup section exists
         if "SETUP" not in config:
-            log.error(f"Config File '{args.configfile}' is missing the required 'SETUP' section")
+            log.error(
+                f"Config File '{args.configfile}' is missing the required 'SETUP' section"
+            )
             exit(1)
         # Process setup section
         pause = config["SETUP"].getint("pause", fallback=60)
@@ -259,6 +294,9 @@ def main():
             porttype = config[section].get("porttype", fallback=None)
             filter = config[section].get("filter", fallback=None)
             excl_filter = config[section].get("exclfilter", fallback=None)
+            udp_port = config[section].get("udpport", fallback=None)
+            mongo_url = config[section].get("mongo_url", fallback=None)
+            mongo_db = config[section].get("mongo_db", fallback=None)
             #
             device_class = get_device_class(_type)
             log.debug(f"device_class {device_class}")
@@ -271,12 +309,12 @@ def main():
                 baud=baud,
                 porttype=porttype,
                 mqtt_broker=mqtt_broker,
-                # mqtt_port=mqtt_port,
-                # mqtt_user=mqtt_user,
-                # mqtt_pass=mqtt_pass,
+                udp_port=udp_port,
+                mongo_url=mongo_url,
+                mongo_db=mongo_db,
             )
             # build array of commands
-            commands = _command.split(",")
+            commands = _command.split("#")
 
             for command in commands:
                 _commands.append((device, command, tag, outputs, filter, excl_filter))
@@ -309,9 +347,9 @@ def main():
             baud=args.baud,
             porttype=args.porttype,
             mqtt_broker=mqtt_broker,
-            # mqtt_port=mqtt_port,
-            # mqtt_user=mqtt_user,
-            # mqtt_pass=mqtt_pass,
+            udp_port=udp_port,
+            mongo_url=mongo_url,
+            mongo_db=mongo_db,
         )
         #
 
@@ -340,7 +378,7 @@ def main():
             # run the command
             commands.append("")
         else:
-            commands = args.command.split(",")
+            commands = args.command.split("#")
 
         outputs = args.output
         for command in commands:
@@ -379,6 +417,9 @@ def main():
                     data=results,
                     tag=_tag,
                     mqtt_broker=mqtt_broker,
+                    udp_port=udp_port,
+                    mongo_url=mongo_url,
+                    mongo_db=mongo_db,
                     # mqtt_port=mqtt_port,
                     # mqtt_user=mqtt_user,
                     # mqtt_pass=mqtt_pass,
@@ -396,3 +437,7 @@ def main():
             # Dont loop unless running as daemon
             log.debug("Not daemon, so not looping")
             break
+
+
+if __name__ == "__main__":
+    main()
