@@ -2,6 +2,7 @@ import json as js
 import logging
 import re
 
+from . import to_json
 from .baseoutput import baseoutput
 from ..helpers import get_kwargs
 from ..helpers import key_wanted
@@ -30,18 +31,5 @@ class json(baseoutput):
         if excl_filter is not None:
             excl_filter = re.compile(excl_filter)
 
-        output = {}
-        for key in data:
-            value = data[key]
-            if isinstance(value, list):
-                value = data[key][0]
-            # unit = data[key][1]
-            # remove spaces
-            key = key.replace(" ", "_")
-            if not keep_case:
-                # make lowercase
-                key = key.lower()
-            if key_wanted(key, filter, excl_filter):
-                output[key] = value
-
+        output = to_json(data, keep_case, excl_filter, filter)
         print(js.dumps(output))
